from django.contrib.sessions.middleware import SessionMiddleware as DjSessionMiddleware
from django.conf import settings
from ipware import get_client_ip


class SessionMiddleware(DjSessionMiddleware):
    def process_request(self, request):
        session_key = request.COOKIES.get(settings.SESSION_COOKIE_NAME)
        request.session = self.SessionStore(
            ip=get_client_ip(request)[0],
            user_agent=request.META.get("HTTP_USER_AGENT", ""),
            session_key=session_key,
        )



from datetime import timedelta

import pytest
from django.conf import settings
from django.contrib import auth
from django.contrib.sessions.backends.base import CreateError
from django.utils.timezone import now

from console_sessions import IP_SESSION_KEY, USER_AGENT_SESSION_KEY
from console_sessions.models import Session

SessionStore = Session.get_session_store_class()


@pytest.fixture(name="store")
def setup_store():
    return SessionStore(user_agent="TestUA/1.1", ip="127.0.0.1")


def test_untouched_init(store):
    assert store.modified is False
    assert store.accessed is False
    assert store.get("cat") is None


def test_store(store):
    store["cat"] = "dog"
    assert store.accessed is True
    assert store.modified is True
    assert "cat" in store
    assert store.pop("cat") == "dog"
    assert "cat" not in store
    assert store.get("cat") is None


def test_auth_session_key(store):
    assert auth.SESSION_KEY not in store
    assert store.modified is False
    assert store.accessed is True

    store.get(auth.SESSION_KEY)
    assert store.modified is False

    store[auth.SESSION_KEY] = 1
    assert store.modified is True


@pytest.mark.django_db
def test_save(store, django_user_model):
    django_user_model.objects.create_user(username="test_user")

    store[auth.SESSION_KEY] = 1
    store.save()

    session = Session.objects.get(pk=store.session_key)
    assert session.user_agent == "TestUA/1.1"
    assert session.ip == "127.0.0.1"
    assert session.user_id == 1
    assert now() - timedelta(seconds=5) <= session.modified <= now()


@pytest.mark.django_db
def test_load_unmodified(store, django_user_model):
    django_user_model.objects.create_user(username="test_user")

    store[auth.SESSION_KEY] = 1
    store.save()
    store2 = SessionStore(session_key=store.session_key, user_agent="TestUA/1.1", ip="127.0.0.1")
    store2.load()
    assert store2.get(USER_AGENT_SESSION_KEY) == "TestUA/1.1"
    assert store2.get(IP_SESSION_KEY) == "127.0.0.1"
    assert store2.get(auth.SESSION_KEY) == 1
    assert store2.modified is False


@pytest.mark.django_db
def test_load_modified(store, django_user_model):
    django_user_model.objects.create_user(username="test_user")

    store[auth.SESSION_KEY] = 1
    store.save()
    store2 = SessionStore(
        session_key=store.session_key, user_agent="TestUA/1.1-changed", ip="8.8.8.8"
    )
    store2.load()
    assert store2.get(USER_AGENT_SESSION_KEY) == "TestUA/1.1"
    assert store2.get(IP_SESSION_KEY) == "127.0.0.1"
    assert store2.get(auth.SESSION_KEY) == 1
    assert store2.modified is True

    store2.save()

    assert store2.get(USER_AGENT_SESSION_KEY) == "TestUA/1.1-changed"
    assert store2.get(IP_SESSION_KEY) == "8.8.8.8"


@pytest.mark.django_db
def test_duplicate_create():
    s1 = SessionStore(session_key="DUPLICATE", user_agent="TestUA/1.1", ip="127.0.0.1")
    s1.create()
    s2 = SessionStore(session_key="DUPLICATE", user_agent="TestUA/1.1", ip="127.0.0.1")
    s2.create()
    assert s1.session_key != s2.session_key

    s3 = SessionStore(session_key=s1.session_key, user_agent="TestUA/1.1", ip="127.0.0.1")
    with pytest.raises(CreateError):
        s3.save(must_create=True)


@pytest.mark.django_db
def test_delete(store):
    # not persisted, should just return
    store.delete()

    # create, then delete
    store.create()
    session_key = store.session_key
    store.delete()

    # non-existing sessions, should not raise
    store.delete()
    store.delete(session_key)


@pytest.mark.django_db
def test_clear(store):
    """
    Clearing the session should clear all non-browser information
    """
    store[auth.SESSION_KEY] = 1
    store.clear()
    store.save()

    session = Session.objects.get(pk=store.session_key)
    assert session.user_id is None


def test_import():
    if settings.SESSION_ENGINE.endswith(".cached_db"):
        from console_sessions.backends.cached_db import SessionStore as CachedDBBackend

        assert issubclass(SessionStore, CachedDBBackend)
    elif settings.SESSION_ENGINE.endswith(".db"):
        from console_sessions.backends.db import SessionStore as DBBackend

        assert issubclass(SessionStore, DBBackend)
    else:
        assert False, "Unrecognised Session Engine"



import json

import pytest
from django.conf import settings
from django.contrib.auth import SESSION_KEY
from django.contrib.auth.models import User
from django.urls import reverse

from console_sessions import USER_AGENT_SESSION_KEY
from console_sessions.models import Session


@pytest.mark.django_db
def test_unmodified_session(client):
    client.get("/", HTTP_USER_AGENT="TestUA/1.1")
    assert settings.SESSION_COOKIE_NAME not in client.cookies


@pytest.mark.django_db
@pytest.mark.parametrize("logged_in", (False, True))
def test_modify_session(client, logged_in):
    if logged_in:
        user = User.objects.create_superuser("user", "", "secret")
        client.force_login(user)
    else:
        user = None

    client.get("/read_session/", HTTP_USER_AGENT="TestUA/1.1")
    client.get("/modify_session/", HTTP_USER_AGENT="TestUA/1.1")
    data = json.loads(
        client.get("/read_session/", HTTP_USER_AGENT="TestUA/1.1").content.decode("UTF-8")
    )
    assert data["FOO"] == "BAR"
    assert data[USER_AGENT_SESSION_KEY] == "TestUA/1.1"
    if user:
        assert str(data[SESSION_KEY]) == str(user.id)

    assert settings.SESSION_COOKIE_NAME in client.cookies
    session = Session.objects.get(pk=client.cookies[settings.SESSION_COOKIE_NAME].value)
    assert session.user_agent == "TestUA/1.1"
    assert session.ip == "127.0.0.1"
    assert session.user == user


@pytest.mark.django_db
def test_login(client):
    admin_login_url = reverse("admin:login")
    user = User.objects.create_superuser("user", "", "secret")
    response = client.post(
        admin_login_url,
        data={
            "username": "user",
            "password": "secret",
            "this_is_the_login_form": "1",
            "next": "/admin/"
        },
        HTTP_USER_AGENT="TestUA/1.1",
    )
    assert response.url == "/admin/"
    session = Session.objects.get(pk=client.cookies[settings.SESSION_COOKIE_NAME].value)
    assert user == session.user


@pytest.mark.django_db
def test_long_ua(client):
    client.get("/modify_session/", HTTP_USER_AGENT="a" * 500)



# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-12-19 16:00

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
from django.utils import timezone
import console_sessions.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="Session",
            fields=[
                (
                    "session_key",
                    models.CharField(
                        max_length=40,
                        primary_key=True,
                        serialize=False,
                        verbose_name="session key"
                    ),
                ),
                ("session_data", models.TextField(verbose_name="session data")),
                ("expire_date", models.DateTimeField(db_index=True, verbose_name="expire date")),
                ("user_agent", models.TextField(blank=True, null=True)),
                ("created", models.DateTimeField(default=timezone.now)),
                ("modified", models.DateTimeField(default=timezone.now)),
                ("ip", models.GenericIPAddressField(blank=True, null=True, verbose_name="IP")),
                (
                    "user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL
                    ),
                ),
            ],
            options={
                "verbose_name": "session",
                "abstract": False,
                "verbose_name_plural": "sessions"
            },
            managers=[("objects", console_sessions.models.SessionManager())],
        ),
    ]



# Generated by Django 5.2.9 on 2026-05-04 15:49
from email.policy import default

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('console_sessions', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='session',
            name='credential_id',
            field=models.TextField(null=True, blank=True, default=None),
        ),
        migrations.AddField(
            model_name='session',
            name='last_mfa',
            field=models.DateTimeField(null=True),
        ),
    ]



from importlib import import_module

from django.conf import settings
from django.contrib.sessions.base_session import AbstractBaseSession, BaseSessionManager
from django.core.cache import caches
from django.db import models
from django.utils import timezone
from django.utils.functional import cached_property
from django.utils.translation import gettext_lazy as _

import console_sessions.geoip as geoip


class SessionQuerySet(models.QuerySet):
    def tenant(self, user=None):
        """
        Return only records that the user is qualified to view.

        :param user: User object
        """
        if not user or not user.is_authenticated:
            return self.none()

        try:
            if user.is_system_owner:
                return self.all()
        except AttributeError:
            pass

        try:
            return self.filter(user__in=user.user_relations_cache)
        except AttributeError:
            pass

        return self.filter(user=user)

    def delete(self):
        """
        Delete sessions from both DB and cache (first cache, then DB)
        """
        # noinspection PyPep8Naming
        SessionStore = Session.get_session_store_class()
        prefix = getattr(SessionStore, "cache_key_prefix", None)
        if prefix is not None:
            caches[settings.SESSION_CACHE_ALIAS].delete_many(prefix + s.session_key for s in self)
        return super().delete()


class SessionManager(BaseSessionManager.from_queryset(SessionQuerySet)):
    use_in_migrations = True


class Session(AbstractBaseSession):
    """
    Session objects containing user session information.
    """

    css_icon = 'fas fa-sign-in-alt'

    user = models.ForeignKey(
        getattr(settings, "AUTH_USER_MODEL", "auth.User"),
        null=True,
        on_delete=models.CASCADE,
    )
    user_agent = models.TextField(null=True, blank=True)
    created = models.DateTimeField(default=timezone.now)
    modified = models.DateTimeField(default=timezone.now)
    ip = models.GenericIPAddressField(null=True, blank=True, verbose_name=_("IP"))
    credential_id = models.TextField(null=True, blank=True, default=None)
    last_mfa = models.DateTimeField(null=True)

    objects = SessionManager()

    def __str__(self):
        return f'{self.session_key} for User: {self.user} from IP: {self.ip}'

    @property
    def row_pk(self) -> str:
        """DataTables helper attribute"""
        return f'row_{self.pk}'

    @classmethod
    def get_session_store_class(cls):
        return import_module(settings.SESSION_ENGINE).SessionStore

    def delete(self, *args, **kwargs):
        """
        Delete session from both DB and cache (first cache, then DB)
        """
        # noinspection PyPep8Naming
        SessionStore = Session.get_session_store_class()
        prefix = getattr(SessionStore, "cache_key_prefix", None)
        if prefix is not None:
            caches[settings.SESSION_CACHE_ALIAS].delete(prefix + self.session_key)
        return super(Session, self).delete(*args, **kwargs)

    def location(self) -> str:
        return geoip.ip_to_location(self.ip)

    def location_info(self) -> dict:
        return geoip.ip_to_location_info(self.ip)

    def location_name(self) -> str:
        location = self.location()
        if location:
            return f'{self.ip} in {location}'
        return str(self.ip) if self.ip else ''

    @cached_property
    def device(self) -> dict:
        """
        Describe the user agent of this session, if any
        """
        if self.user_agent:
            from device_detector import SoftwareDetector  # late import to avoid import cost

            return SoftwareDetector(self.user_agent).parse().all_details
        return {}

    def client_name(self) -> str:
        client = self.device.get('client', {})
        name = client.get('name', 'UNK')
        version = client.get('version')
        if version:
            name = f'{name} - {version}'
        return name

    def client_platform(self) -> str:
        os = self.device.get('os', {})
        return os.get('name', 'UNK')



from django.utils.translation import gettext_lazy as _
from django.contrib.auth import get_user_model
from django.utils.html import format_html
from django.utils.timezone import now
from django.contrib import admin
from django.urls import reverse
from .models import Session
from pprint import pformat


def linkify(field_name):
    """
    Converts a foreign key value into clickable links.
    """

    def _linkify(obj):
        linked_obj = getattr(obj, field_name)
        if linked_obj is None:
            return "-"
        app_label = linked_obj._meta.app_label
        model_name = linked_obj._meta.model_name
        view_name = f"admin:{app_label}_{model_name}_change"
        link_url = reverse(view_name, args=[linked_obj.pk])
        return format_html('<a href="{}">{}</a>', link_url, linked_obj)

    _linkify.short_description = field_name  # Sets column name
    return _linkify


class ExpiredFilter(admin.SimpleListFilter):
    title = _("Is Valid")
    parameter_name = "active"

    def lookups(self, request, model_admin):
        return [("1", _("Active")), ("0", _("Expired"))]

    def queryset(self, request, queryset):
        if self.value() == "1":
            return queryset.filter(expire_date__gt=now())
        elif self.value() == "0":
            return queryset.filter(expire_date__lte=now())


class OwnerFilter(admin.SimpleListFilter):
    title = _("Owner")
    parameter_name = "owner"

    def lookups(self, request, model_admin):
        return [("my", _("Self"))]

    def queryset(self, request, queryset):
        if self.value() == "my":
            return queryset.filter(user=request.user)


@admin.register(Session)
class SessionAdmin(admin.ModelAdmin):
    list_display = (
        "ip",
        linkify("user"),
        "is_valid",
        "created",
        "expire_date",
        "device",
        "location",
        "credential_id",
    )
    list_select_related = ("user",)
    readonly_fields = (
        "ip",
        "location",
        "user",
        "user_agent",
        "is_valid",
        "expire_date",
        "created",
        "modified",
        "user_agent",
        "device",
        "session_key",
        "session_data_decoded",
    )
    list_filter = ExpiredFilter, OwnerFilter
    fields = (
        "user",
        "ip",
        "location",
        "is_valid",
        "created",
        "modified",
        "expire_date",
        "user_agent",
        "device",
        "credential_id",
        "session_key",
        "session_data_decoded",
    )
    ordering = ("-expire_date",)

    def get_search_fields(self, request):
        # noinspection PyPep8Naming
        User = get_user_model()
        return (
            "ip",
            "user__%s" % getattr(User, "USERNAME_FIELD", "username"),
            "user__%s" % getattr(User, "USERNAME_EMAIL", "email"),
        )

    def is_valid(self, obj):
        return obj.expire_date > now()

    is_valid.boolean = True
    is_valid.short_description = _("Is valid")

    def session_data_decoded(self, obj):
        return format_html(
            '<pre style="white-space: pre-wrap; max-width: 800px; display: inline-block; direction: ltr;">{}</pre>',
            pformat(obj.get_decoded()),
        )

    session_data_decoded.short_description = _("Session data")



from __future__ import unicode_literals

import pytest
from django.contrib import auth

from console_sessions import IP_SESSION_KEY, USER_AGENT_SESSION_KEY
from console_sessions.models import Session

SessionStore = Session.get_session_store_class()


@pytest.mark.django_db
def test_get_decoded(django_user_model):
    django_user_model.objects.create_user(username="test_user")

    store = SessionStore(user_agent="TestUA/1.1", ip="127.0.0.1")
    store[auth.SESSION_KEY] = 1
    store["foo"] = "bar"
    store.save()

    session = Session.objects.get(pk=store.session_key)
    assert session.get_decoded() == {
        "foo": "bar",
        auth.SESSION_KEY: 1,
        IP_SESSION_KEY: "127.0.0.1",
        USER_AGENT_SESSION_KEY: "TestUA/1.1",
    }


def test_location():
    session = Session(ip="89.160.20.112")
    assert session.location() == "Linköping, Sweden"
    loc_info = session.location_info()
    assert loc_info["city"] == "Linköping"
    assert loc_info["country_code"] == "SE"

    # This depends on Django version, so be safe
    assert loc_info.get("continent_code") == "EU" or loc_info.get("region") == "E"


def test_device():
    session = Session(
        user_agent=(
            "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) "
            "AppleWebKit/537.36 (KHTML, like Gecko) "
            "Chrome/70.0.3538.102 Safari/537.36"
        )
    )
    device = session.device
    assert device['os']['family'] == "Mac"
    assert device['client']['name'] == "Chrome"


@pytest.mark.django_db
def test_delete():
    """
    Session.delete should delete session from both DB and cache
    """
    store = SessionStore(user_agent="TestUA/1.1", ip="127.0.0.1")
    store.create()
    session_key = store.session_key

    session = Session.objects.get(pk=session_key)
    session.delete()

    assert not store.exists(session_key)


@pytest.mark.django_db
def test_bulk_delete_from_both_cache_and_db():
    s1 = SessionStore(user_agent="Python/2.7", ip="127.0.0.1")
    s1.create()
    s2 = SessionStore(user_agent="Python/2.7", ip="127.0.0.1")
    s2.create()
    s3 = SessionStore(user_agent="TestUA/1.1", ip="127.0.0.1")
    s3.create()
    assert s1.exists(s1.session_key)
    assert s2.exists(s2.session_key)
    assert s3.exists(s3.session_key)

    Session.objects.filter(user_agent="Python/2.7").delete()

    assert not s1.exists(s1.session_key)
    assert not s2.exists(s2.session_key)
    assert s3.exists(s3.session_key)



from __future__ import unicode_literals

import pytest
from django.conf import settings


@pytest.mark.django_db
@pytest.mark.filterwarnings("ignore:The address 127.0.0.1 is not in the database")
def test_smoke_admin(admin_client):
    admin_client.get(
        "/modify_session/", HTTP_USER_AGENT="Chrome/70.0.3538.102", REMOTE_ADDR="89.160.20.112"
    )
    resp = admin_client.get("/admin/console_sessions/session/?active=1&owner=my")
    assert resp.status_code == 200
    content = resp.content.decode("UTF-8")

    assert "Linköping, Sweden" in content  # From REMOTE_ADDR
    resp = admin_client.get(
        "/admin/console_sessions/session/%s/change/" %
        admin_client.cookies[settings.SESSION_COOKIE_NAME].value
    )
    assert "FOO" in resp.content.decode("UTF-8")  # Set by modify_session



from lchttp.json import json_dumps, json_loads

from django.contrib import auth
from django.contrib.sessions.backends.db import SessionStore as DjangoDBStore
from django.utils import timezone

from console_sessions import (
    CREDENTIAL_ID_SESSION_KEY,
    SESSION_LAST_MODIFIED_KEY,
    IP_SESSION_KEY,
    LAST_MFA_SESSION_KEY,
    USER_AGENT_SESSION_KEY,
)


class SessionStore(DjangoDBStore):
    """
    Implements database backed sessions, with a foreign key to User.
    It also stores IP and User Agent.
    """

    def __init__(
        self,
        session_key=None,
        user_agent=None,
        ip=None,
        credential_id=None,
        last_mfa=None,
    ):
        self.user_agent = user_agent
        self.ip = ip
        self.credential_id = credential_id
        self.last_mfa = last_mfa
        super().__init__(session_key)

    @classmethod
    def get_model_class(cls):
        from console_sessions.models import Session

        return Session

    def load(self):
        data = super().load()
        if (
            data.get(USER_AGENT_SESSION_KEY) != self.user_agent
            or data.get(IP_SESSION_KEY) != self.ip
        ):
            # If IP or User Agent has changed, set modified to True in order to save
            # the new IP and User Agent
            self.modified = True
        return data

    def save(self, must_create=False):
        # Store IP and User Agent in session_data
        if USER_AGENT_SESSION_KEY not in self or self[USER_AGENT_SESSION_KEY] != self.user_agent:
            self[USER_AGENT_SESSION_KEY] = self.user_agent
        if IP_SESSION_KEY not in self or self[IP_SESSION_KEY] != self.ip:
            self[IP_SESSION_KEY] = self.ip

        self.save_mfa_properties()

        super().save(must_create)

    def save_mfa_properties(self):
        """
        MFA Properties will almost always be saved by mutating an existing session.
        """
        if CREDENTIAL_ID_SESSION_KEY in self and not self.credential_id:
            self.credential_id = self[CREDENTIAL_ID_SESSION_KEY]
        elif self.credential_id:
            self[CREDENTIAL_ID_SESSION_KEY] = self.credential_id

        if LAST_MFA_SESSION_KEY in self and not self.last_mfa:
            self.last_mfa = self[LAST_MFA_SESSION_KEY]
        elif self.last_mfa:
            self[LAST_MFA_SESSION_KEY] = self.last_mfa

    def create_model_instance(self, data):
        # Store User, User Agent, IP, Credential ID, and Last MFA in Session (in DB).

        # Save "last_modified" to session data,
        # to easily check recent activity in views.
        if self.modified:
            data[SESSION_LAST_MODIFIED_KEY] = timezone.now()

        try:
            session_data = self.encode(data)
        except TypeError:
            # Dump to json and back to convert any UUIDs that might be in the
            # session data as Django's default serializer doesn't support UUIDs.
            session_data = self.encode(json_loads(json_dumps(data)))

        return self.model(
            modified=data.get(SESSION_LAST_MODIFIED_KEY, timezone.now()),
            session_key=self._get_or_create_session_key(),
            session_data=session_data,
            expire_date=self.get_expiry_date(),
            user_id=self.get(auth.SESSION_KEY),
            user_agent=self.user_agent,
            ip=self.ip,
            credential_id=self.credential_id,
            last_mfa=self.last_mfa,
        )



from django.contrib import admin
from django.http import HttpResponse, JsonResponse
from django.urls import re_path


def read_session(request):
    return JsonResponse(dict(request.session))


def modify_session(request):
    request.session["FOO"] = "BAR"
    return HttpResponse("")


urlpatterns = [
    re_path(r"^read_session/$", read_session),
    re_path(r"^modify_session/$", modify_session),
    re_path(r"^admin/", admin.site.urls),
]



from django.contrib.sessions.backends.cached_db import SessionStore as DjangoCachedDBStore

from .db import SessionStore as ConsoleSessionsDBStore

KEY_PREFIX = "console_sessions.q_cached_db"


class SessionStore(ConsoleSessionsDBStore, DjangoCachedDBStore):
    """
    Implements cached, database backed sessions, with a foreign key to User.
    It also stores IP and User Agent.
    """

    cache_key_prefix = KEY_PREFIX



CREDENTIAL_ID_SESSION_KEY = "_console_sessions_credential_id"
IP_SESSION_KEY = "_console_sessions_ip"
LAST_MFA_SESSION_KEY = "_console_sessions_last_mfa"
SESSION_LAST_MODIFIED_KEY = "_console_sessions_last_modified"
USER_AGENT_SESSION_KEY = "_console_sessions_user_agent"



import os
from setuptools import setup, find_packages

with open(os.path.join(os.path.dirname(__file__), "README.rst"), encoding="UTF-8") as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

dev_requirements = [
    "geoip2",  # for testing GeoIP2
    "pytest",
    "pytest-cov",
    "pytest-django",
]

setup(
    name="console-sessions",
    version="0.3.0",
    description="Console session backends for Compass projects",
    long_description=README,
    author="Dave Burkholder",
    url="https://code.compassfoundation.io/clavis/console-sessions",
    license="SAP",
    packages=find_packages(".", include=("console_sessions", "console_sessions.*")),
    include_package_data=True,
    install_requires=[
        "django",
        "django-ipware",
        "geoip2",
    ],
    extras_require={"dev": dev_requirements},
    tests_require=dev_requirements,
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Framework :: Django :: 3.1",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.9",
        "Topic :: Internet :: WWW/HTTP :: Session",
        "Topic :: Security",
    ],
)



import os

BASE_DIR = os.path.dirname(os.path.abspath(__file__))
SECRET_KEY = "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA"

DEBUG = True

INSTALLED_APPS = [
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "console_sessions",
    "django.contrib.messages",
]

MIDDLEWARE = [
    "console_sessions.middleware.SessionMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
]

ROOT_URLCONF = "tests.urls"

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
            ],
        },
    },
]

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": os.path.join(BASE_DIR, "db.sqlite3"),
    }
}

STATIC_URL = "/static/"

GEOIP_PATH = os.path.join(BASE_DIR, "geoip")
GEOIP_CITY = "GeoIP2-City-Test.mmdb"
GEOIP_COUNTRY = "GeoIP2-Country-Test.mmdb"
